@@ -1,6 +1,8 @@
 import asyncio
 import logging
-from typing import Any
+from concurrent.futures import ThreadPoolExecutor
+from inspect import iscoroutine
+from typing import Any, Awaitable, Callable, Coroutine
 
 
 class PyNotiTask(object):
@@ -8,6 +10,7 @@ class PyNotiTask(object):
     __preprocessor: callable = None
     __delay: float = 0
     __fn: callable = None
+    __is_async: bool = False
     __args: Any = None
     __kwargs: dict[str, Any] = None
     __timer_handle: asyncio.TimerHandle = None
@@ -27,6 +30,19 @@ class PyNotiTask(object):
         self.__fn = fn
         self.__args = args
         self.__kwargs = kwargs
+        self.__is_async = False
+
+    @property
+    def task_id(self) -> str:
+        return self.__task_id
+
+    @property
+    def is_async(self) -> bool:
+        return self.__is_async
+
+    @is_async.setter
+    def is_async(self, is_async: bool):
+        self.__is_async = is_async
 
     @property
     def delay(self) -> float:
@@ -65,3 +81,16 @@ class PyNotiTask(object):
                 self.__fn(*self.__args, **self.__kwargs)
         except Exception as e:
             logging.error(e)
+
+    async def async_execute(self):
+        if self.__fn is None:
+            return
+        logging.debug(f"Task[{self.__task_id}] execute.")
+        try:
+            handled = False
+            if self.__preprocessor is not None:
+                handled = self.__preprocessor(self.__fn, *self.__args, **self.__kwargs)
+            if not handled:
+                await self.__fn(*self.__args, **self.__kwargs)
+        except Exception as e:
+            logging.error(e)
